%define oname		aMule

%define date		20211122

%if %{date}
%define release		%mkrel -c git%{date} %{rel}
%define tarballver	%{commit}
%define tarballdir	%{commit}
%define tarballgit	+git%{date}
%define commit		8fd81283f7c480afc31912c873f94c3f126496a0
%else
%define release		%mkrel %{rel}
%define tarballver	%{version}
%define tarballdir	%{version}
%endif

%define rel	2

Name:		amule
Version:	2.4.0
Release:	%{release}
Summary:	File sharing client compatible with eDonkey
License:	GPLv2
Group:		Networking/File transfer
URL:		https://amule.org
Source:		https://github.com/amule-project/amule/archive/%{tarballdir}/%{name}-%{version}%{?tarballgit}.tar.gz
Patch0:		amule-2.4.0-version_check.patch

BuildRequires:	bison
BuildRequires:	cmake
BuildRequires:	flex
BuildRequires:	imagemagick
BuildRequires:	desktop-file-utils
BuildRequires:	binutils-devel
BuildRequires:	boost-devel
BuildRequires:	gettext-devel
BuildRequires:	wxgtk3.0-devel
BuildRequires:	pkgconfig(cryptopp)
BuildRequires:	pkgconfig(gdlib) >= 2.0
BuildRequires:	pkgconfig(geoip)
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(libupnp)
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	pkgconfig(readline)

%description
aMule is an easy to use multi-platform client for ED2K Peer-to-Peer Network. It
is a fork of xMule, whis was based on emule for Windows. aMule currently
supports (but is not limited to) the following platforms: Linux, *BSD and
MacOSX.

#------------------------------------------------------------------------------

%package	commandline
Summary:	File sharing client compatible with eDonkey
Group:		Networking/File transfer
Requires:	%{name} = %{version}-%{release}

%description	commandline
aMule is an easy to use multi-platform client for ED2K Peer-to-Peer Network. It
is a fork of xMule, whis was based on emule for Windows. aMule currently
supports (but is not limited to) the following platforms: Linux, *BSD and
MacOSX.

This is the command line tool to control aMule remotely (or locally:).

#------------------------------------------------------------------------------

%package	webserver
Summary:	File sharing client compatible with eDonkey
Group:		Networking/File transfer
Requires:	%{name}

%description	webserver
aMule is an easy to use multi-platform client for ED2K Peer-to-Peer Network. It
is a fork of xMule, whis was based on emule for Windows. aMule currently
supports (but is not limited to) the following platforms: Linux, *BSD and
MacOSX.

This is the webserver to control aMule remotely (or locally:).

#------------------------------------------------------------------------------
%prep
%setup -q -n %{name}-%{tarballver}
%autopatch -p1

# fix GIT version tag name
sed -i -e 's|VERSION "GIT"|VERSION "%{version} GIT"|' CMakeLists.txt

sed -i 's|unset (\${CMAKE_REQUIRED_LIBRARIES})|#unset (\${CMAKE_REQUIRED_LIBRARIES})|' cmake/bfd.cmake

%build
%cmake \
	-DENABLE_BOOST=ON      \
	-DBUILD_AMULECMD=ON    \
	-DBUILD_REMOTEGUI=ON   \
	-DBUILD_WEBSERVER=ON   \
	-DBUILD_CAS=ON         \
	-DBUILD_WXCAS=ON       \
	-DBUILD_ALC=ON         \
	-DBUILD_ALCC=ON        \
	-DBUILD_DAEMON=ON      \
	-DENABLE_IP2COUNTRY=ON \
	-DBUILD_FILEVIEW=ON    \
	-DBUILD_XAS=ON         \
	-DSVNDATE="rev. %{date}"
%cmake_build

%install
%cmake_install

for png in 128x128 48x48 32x32 16x16; do
  mkdir -p %{buildroot}%{_iconsdir}/hicolor/${png}/apps/
  convert -geometry $png amule.png %{buildroot}%{_iconsdir}/hicolor/${png}/apps/%{name}.png
done

mkdir -p %{buildroot}%{_menudir}

# Fix wrong-script-end-of-line-encoding
perl -pi -e 's/\015$//' %{buildroot}%{_datadir}/doc/%{name}-%{version}/%{name}-win32.HOWTO.txt

mv %{buildroot}%{_bindir}/ed2k %{buildroot}%{_bindir}/ed2k-%{name}
rm -f %{buildroot}%{_datadir}/doc/%{name}-%{version}/man/.cvsignore
rm -rf %{buildroot}%{_datadir}/doc/%{oname}-%{version}
rm -f %{buildroot}%{_libdir}/xchat/plugins/xas.pl

desktop-file-install --vendor="" \
	--add-category="GTK" \
	--add-category="FileTransfer" \
	--dir %{buildroot}%{_datadir}/applications %{buildroot}%{_datadir}/applications/*.desktop

%find_lang %{name} --with-man
%find_lang alc --with-man
%find_lang amulegui --with-man
%find_lang cas --with-man
%find_lang ed2k --with-man
%find_lang wxcas --with-man
%find_lang xas --with-man
cat alc.lang amulegui.lang cas.lang ed2k.lang wxcas.lang xas.lang  >> %{name}.lang

%find_lang alcc --with-man
%find_lang amulecmd --with-man
%find_lang amuled --with-man
cat alcc.lang amulecmd.lang amuled.lang  > %{name}-commandline.lang

%find_lang amuleweb --with-man
cat amuleweb.lang  > %{name}-webserver.lang

%post
update-alternatives --install %{_bindir}/ed2k ed2k %{_bindir}/ed2k-%{name} 5

%postun
update-alternatives --remove ed2k %{_bindir}/ed2k-%{name}

%files -f %{name}.lang
%doc docs/{ABOUT-NLS,AUTHORS,Changelog,README,README.Asio.txt,TODO}
%doc docs/{amulesig.txt,EC_Protocol.txt,license.txt,Releases.dia}
%license docs/COPYING
%exclude %{_docdir}/%{name}/INSTALL
%dir %{_datadir}/%{name}
%{_bindir}/%{name}*
%{_bindir}/autostart-xas
%{_bindir}/wxcas
%{_bindir}/cas
%{_bindir}/ed2k-%{name}
%{_bindir}/alc
%{_bindir}/fileview
%{_datadir}/%{name}/skins
%{_datadir}/cas
%{_datadir}/applications/%{name}*.desktop
%{_datadir}/applications/alc.desktop
%{_datadir}/applications/wxcas.desktop
%{_datadir}/pixmaps/%{name}*.xpm
%{_datadir}/pixmaps/alc.xpm
%{_datadir}/pixmaps/wxcas.xpm
%{_iconsdir}/hicolor/*/apps/%{name}.png
%{_mandir}/man1/alc.1*
%{_mandir}/man1/%{name}*.1*
%{_mandir}/man1/cas.1*
%{_mandir}/man1/ed2k.1*
%{_mandir}/man1/wxcas.1*
%{_mandir}/man1/xas.1*

%files commandline -f %{name}-commandline.lang
%{_bindir}/%{name}cmd
%{_bindir}/alcc
%{_bindir}/%{name}d
%{_mandir}/man1/alcc.1*
%{_mandir}/man1/%{name}cmd.1*
%{_mandir}/man1/%{name}d.1*

%files webserver -f %{name}-webserver.lang
%{_bindir}/%{name}web
%{_datadir}/%{name}/webserver/*
%{_mandir}/man1/amuleweb.1*


%changelog
* Sat Jul 16 2022 wally <wally> 2.4.0-0.git20211122.2.mga9
+ Revision: 1869179
- build against wxgtk3.0

* Thu Dec 02 2021 joequant <joequant> 2.4.0-0.git20211122.1.mga9
+ Revision: 1760526
- rebuild with new version using wx-3.1

* Sat Aug 28 2021 joequant <joequant> 2.4.0-0.git20210426.2.mga9
+ Revision: 1743202
- rebuild with new libraries

* Mon May 03 2021 daviddavid <daviddavid> 2.4.0-0.git20210426.1.mga9
+ Revision: 1721107
- update to latest git snapshot: 2.4.0-git20210426

* Tue Dec 15 2020 daviddavid <daviddavid> 2.4.0-0.git20201016.1.mga8
+ Revision: 1657691
- update to latest git snapshot: 2.4.0-git20201016

* Thu Dec 03 2020 luigiwalser <luigiwalser> 2.4.0-0.git20200812.2.mga8
+ Revision: 1652222
- add upstream commit to fix building with libupnp 1.14.0
- rebuild for libupnp

* Mon Sep 14 2020 daviddavid <daviddavid> 2.4.0-0.git20200812.1.mga8
+ Revision: 1626279
- update to latest git snapshot: 2.4.0-git20200812
- switch to wxgtk 3.0 as latest wxgtk 3.1.4 cause crashes (mga#27250)

* Sun Aug 16 2020 wally <wally> 2.4.0-0.git20200518.2.mga8
+ Revision: 1614323
- rebuild for new wxgtk 3.1.4

* Sun May 24 2020 wally <wally> 2.4.0-0.git20200518.1.mga8
+ Revision: 1587350
- update to latest snapshot
- rebuild for new libupnp 1.12.1

* Thu Apr 16 2020 danf <danf> 2.4.0-0.git20191118.4.mga8
+ Revision: 1567878
- Add bfd.patch to fix compilation with binutils 2.34

* Sun Jan 26 2020 wally <wally> 2.4.0-0.git20191118.3.mga8
+ Revision: 1483339
- rebuild for boost 1.72.0
- replace deprecated %%configure2_5x

* Sat Jan 04 2020 luigiwalser <luigiwalser> 2.4.0-0.git20191118.2.mga8
+ Revision: 1475926
- rebuild for readline

* Wed Nov 27 2019 daviddavid <daviddavid> 2.4.0-0.git20191118.1.mga8
+ Revision: 1463052
- update to latest git snapshot: 2.4.0-git20191118

* Tue Nov 26 2019 daviddavid <daviddavid> 2.4.0-0.git20190521.4.mga8
+ Revision: 1463031
- rebuild for new libcryptopp 8.2.0

* Tue Nov 12 2019 wally <wally> 2.4.0-0.git20190521.3.mga8
+ Revision: 1459449
- rebuild for wxgtk 3.1.3

* Mon Jul 08 2019 wally <wally> 2.4.0-0.git20190521.2.mga8
+ Revision: 1419518
- rebuild for wxgtk 3.1.2 with 2.8 compatibility

* Sun Jul 07 2019 wally <wally> 2.4.0-0.git20190521.1.mga8
+ Revision: 1419290
- new snapshot 20190521
- build with gtk3 enabled wxgtk 3.1.2

* Thu May 02 2019 daviddavid <daviddavid> 2.4.0-0.git20190430.1.mga7
+ Revision: 1396124
- update to latest git snapshot: 2.4.0-git20190430

* Tue Jan 01 2019 daviddavid <daviddavid> 2.4.0-0.git20181119.1.mga7
+ Revision: 1348050
- update to latest git snapshot: 2.4.0-git20181119
- add patch to fix build with new libupnp >= 1.8
- disable NewVersionCheck by Default
+ luigiwalser <luigiwalser>
- rebuild for libupnp

* Tue Oct 16 2018 wally <wally> 2.4.0-0.git20180521.2.mga7
+ Revision: 1321006
- rebuild for new boost 1.68.0

* Sun Sep 16 2018 daviddavid <daviddavid> 2.4.0-0.git20180521.1.mga7
+ Revision: 1259210
- update to latest git snapshot: 2.4.0-git20180521
- rebuild for new libcryptopp 7.0.0

* Mon Dec 25 2017 wally <wally> 2.4.0-0.git20161207.5.mga7
+ Revision: 1184649
- rebuild for new boost

* Tue Nov 21 2017 tv <tv> 2.4.0-0.git20161207.4.mga7
+ Revision: 1178308
- rebuild for boost 1.65

* Sat Sep 16 2017 tv <tv> 2.4.0-0.git20161207.3.mga7
+ Revision: 1154670
- rebuild with latest boost

* Sat Jun 03 2017 akien <akien> 2.4.0-0.git20161207.2.mga6
+ Revision: 1106082
- Rebuild for wxgtk 3.0.3.1

* Sat Jan 14 2017 daviddavid <daviddavid> 2.4.0-0.git20161207.1.mga6
+ Revision: 1081613
- update to latest git snapshot: 2.4.0-git20161207
- rebuild for new libcryptopp (mga#20120)

* Tue Oct 04 2016 daviddavid <daviddavid> 2.4.0-0.git20160926.1.mga6
+ Revision: 1058695
- update to latest git snapshot: 2.4.0-git20160926
- port to wxgtk3

* Sat Jul 09 2016 daviddavid <daviddavid> 2.4.0-0.git20160607.1.mga6
+ Revision: 1039947
- update to latest git snapshot: 2.4.0-git20160607
- rebuild against fixed libgd

* Wed Apr 27 2016 daviddavid <daviddavid> 2.4.0-0.git20160416.1.mga6
+ Revision: 1006892
- new version: 2.4.0-git20160416 (pre-release)
  * commit: 393acf5ce78dfdabd7316c44a78511db1c7bae74

* Wed Apr 27 2016 daviddavid <daviddavid> 2.4.0-0.git20160103.2.mga6
+ Revision: 1006876
- rebuild against libcryptopp 5.6.3 (fixes mga#18272)

* Mon Jan 04 2016 daviddavid <daviddavid> 2.4.0-0.git20160103.1.mga6
+ Revision: 919646
- new version: 2.4.0-git20160103 (pre-release)
  * commit: 13596819eeaf2334ad1a99981c6e1e2f8ddb953b
- update Source URL
- enable boost support

* Thu Sep 03 2015 cjw <cjw> 2.3.1-13.mga6
+ Revision: 872617
- rebuild with gcc 5

* Mon Feb 16 2015 oden <oden> 2.3.1-12.mga5
+ Revision: 815140
- rebuilt for libgd-2.1.1

* Wed Oct 15 2014 umeabot <umeabot> 2.3.1-11.mga5
+ Revision: 739213
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 luigiwalser <luigiwalser> 2.3.1-10.mga5
+ Revision: 685710
- move rename macro usage to correct place in spec file
+ umeabot <umeabot>
- Mageia 5 Mass Rebuild

* Sun Mar 30 2014 david-david <david-david> 2.3.1-8.mga5
+ Revision: 610360
- use better icon amule from tarball
- add BR imagemagick
- update License
- update link url for Source

* Sat Oct 19 2013 umeabot <umeabot> 2.3.1-7.mga4
+ Revision: 526042
- Mageia 4 Mass Rebuild

* Mon Jun 03 2013 fwang <fwang> 2.3.1-6.mga4
+ Revision: 435780
- rebuild for new libpng

* Tue May 28 2013 oden <oden> 2.3.1-5.mga4
+ Revision: 429280
- rebuilt against libgd.so.3

* Sun Mar 17 2013 lmenut <lmenut> 2.3.1-4.mga3
+ Revision: 403587
- rebuild for new rpm-mageia-setup (mga #9055)

* Fri Jan 11 2013 umeabot <umeabot> 2.3.1-3.mga3
+ Revision: 345533
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Jan 07 2013 sander85 <sander85> 2.3.1-2.mga3
+ Revision: 341146
- Rebuild with fixed libcryptopp

* Sat Jan 28 2012 kamil <kamil> 2.3.1-1.mga2
+ Revision: 202574
- new version 2.3.1
- use %%find_lang for man-pages
- clean .spec

* Mon Oct 31 2011 dmorgan <dmorgan> 2.3.1-0.rc2.1.mga2
+ Revision: 160520
- New version 2.3.1 rc2

* Wed Sep 21 2011 fwang <fwang> 2.3.1-0.rc1.4.mga2
+ Revision: 146203
- rebuild for new libpng
- rebuild for new libupnp
+ ahmad <ahmad>
- Replace libgeoip-devel with geoip-devel

* Sun May 08 2011 dmorgan <dmorgan> 2.3.1-0.rc1.2.mga1
+ Revision: 95964
- Remove PLF Reason

* Sun May 08 2011 dmorgan <dmorgan> 2.3.1-0.rc1.1.mga1
+ Revision: 95963
- Fix file list
- Fix typo
- Update to 2.3.1 Rc1
- Do not apply patch0
- imported package amule

